ImageNet-Sketch consists of 50,889 black and white sketch images, 50 for each of
the 1000 ImageNet classes. These images were originally collected from Google
Image Search for "sketch of __". 100 images were collected and then manually
filtered. For classes with fewer than 50 good images, additional images were
constructed by flip or rotation.
